gsmtap_makemsg_ex: NULL for unknown chan_type

Related: osmo-bts Ic22ab71e520ab44429a93724250d349d16250801
Change-Id: Ib4147a33a75c3cf425c30da8b0678c7fba8a371d
diff --git a/src/gsmtap_util.c b/src/gsmtap_util.c
index 9a0ac02..8674f1c 100644
--- a/src/gsmtap_util.c
+++ b/src/gsmtap_util.c
@@ -169,7 +169,8 @@
  *  \param[in] snr Signal/Noise Ratio (SNR)
  *  \param[in] data Pointer to data buffer
  *  \param[in] len Length of \ref data
  *  \return dynamically allocated message buffer containing data
  *
  * This function will allocate a new msgb and fill it with a GSMTAP
  * header containing the information
@@ -182,6 +183,9 @@
 	struct gsmtap_hdr *gh;
 	uint8_t *dst;
 
+	if (chan_type == GSMTAP_CHANNEL_UNKNOWN)
+		return NULL;
+
 	msg = msgb_alloc(sizeof(*gh) + len, "gsmtap_tx");
 	if (!msg)
 		return NULL;
@@ -169,7 +169,8 @@
  *  \param[in] data Pointer to data buffer
  *  \param[in] len Length of \ref data
- *  \return dynamically allocated message buffer containing data
+ *  \return dynamically allocated message buffer containing data,
+ *          or NULL for unknown chan_type
  *
  * This function will allocate a new msgb and fill it with a GSMTAP